/* ===============================================================

   config.h -- This file belongs to the nano-archimedes.

   nano-archimedes is a quantum mechanical simulator
   which implements the single-body Wigner Monte Carlo method.
   This code simulates a Gaussian wave-packet going towards
   a potential barrier.

   Copyright (C) 2004-2014 Jean Michel D. Sellier
   <jeanmichel.sellier@gmail.com>
   <jeanmichel.sellier@parallel.bas.bg>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.

   ===============================================================
*/

// === initial configuration of the wave packet ===
// === Gaussian wave packet ===

void devconf(void){
 register int i,j;

 // calculate initial distribution function
 printf("config() - calculating initial distribution\n");
 for(i=1;i<=NX;i++)
  for(j=-NKX+1;j<NKX;j++){
   DIST[i][j+NKX-1]=(int)(INUM
                  *exp(-pow(((i-0.5)*DX-X0_WAVE_PACKET)/SIGMA_WAVE_PACKET,2.))
                  *exp(-pow(((j*DKX)-K0_WAVE_PACKET)*SIGMA_WAVE_PACKET,2.)));
  }
 annihilation();
 printf("Initial Number of Electron Super-particles = %d\n", INUM);
}

// ==============================================================
